@@ -1,6 +1,5 @@
 package Lingua::JA::WebIDF::API::Bing;
 
-use 5.008_001;
 use strict;
 use warnings;
 
@@ -13,17 +12,14 @@ our $BASE_URL = 'http://api.bing.net/json.aspx';
 
 sub fetch_new_df
 {
-    my ($self, $word) = @_;
-
-    my $api  = $self->{api};
-    my $furl = $self->{furl_http};
+    my ($word, $furl, $appid) = @_;
 
     my $df;
 
     my $url = URI->new($BASE_URL);
 
     $url->query_form(
-        'Appid'     => $self->{appid},
+        'Appid'     => $appid,
         'query'     => qq|"$word"|,
         'sources'   => 'web',
         'web.count' => 1,
@@ -36,7 +32,7 @@ sub fetch_new_df
         my $json = JSON::decode_json($body);
         $df = $json->{SearchResponse}{Web}{Total};
     }
-    else { Carp::carp("$api: $code $msg"); }
+    else { Carp::carp("Bing: $code $msg"); }
 
     return $df;
 }
